import React, { useState, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { csv, path, curveLinear, line, scaleBand, scaleLinear, scaleOrdinal, max, min, extent } from 'd3';

const csvUrl = 'https://gist.githubusercontent.com/curran/a08a1080b88344b0c8a7/raw/0e7a9b0a5d22642a06d3d5b9bcbad9890c8ee534/iris.csv';
const width = 900;
const height = 450;
const margin = { left: 40, right: 40, top: 20, bottom: 65 };

const App = () => {
  const [data, setData] = useState(null);
  
  useEffect(() => {
  	csv(csvUrl).then(setData);
  }, []);
  
  if (!data) {
    return <div>Loading...</div>;
  }
  
  const xValue = d => d.sepal_length;
  const yValue = d => d.sepal_width;
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  //innerHeight = 375
  //innerWidth = 820
  
  const xScale = scaleLinear().domain(extent(data,xValue)).range([0, innerWidth]);
  const yScale = scaleLinear().domain(extent(data,yValue)).range([innerHeight, 0]);
  const colorScale = scaleOrdinal().domain(data.map(d => d.species)).range(['red','blue','green']);
  const line1 = [[0,0], [10, 325], [370, 130], [370, 160], [720, 20]]
	const line2 = [[10, 375], [10, 325], [370, 130], [370, 160], [570, 325]]
  const line3 = [[570, 325], [370, 160], [720, 20], [820, 50], [820, 275]]
  return (
  	<>
      <svg width={width} height={height}>
        <g transform={`translate(${margin.left},${margin.top})`}>
          {
          	xScale.ticks().map(tickValue => <g className="tick" transform={`translate(${xScale(tickValue)},${innerHeight+3})`}>
                                 <text
                                   style={{textAnchor: 'middle'}}
                                   dy="0.71em"
                                   >{tickValue}</text>
                                 <line 
                                   y1={-innerHeight}
                                   y2={-3}
                                   />
                               </g>) 
          }
          {
          	yScale.ticks().map(tickValue => <g className="tick" transform={`translate(0, ${yScale(tickValue)})`}>
                                 <text
                                   dy="0.32em"
                                   x={-3}
                                   style={{textAnchor: 'end'}}
                                   >{tickValue}</text>
                                 <line 
                                   x2={innerWidth}
                                   />
                               </g>)  
          }
          <g className="axis-label" transform={`translate(0,0)`}>
          	<line 
              y2={innerHeight}
              />
          </g>
          <g className="axis-label" transform={`translate(0,${innerHeight})`}>
          	<line 
              x2={innerWidth}
              />
          </g>
          <g>
          <path 
            fill='rgba(255,0,0,0.2)'
            d={line().x(d => d[0]).y(d => d[1])(line1)}
          />
          <path 
            fill='rgba(0,0,255,0.2)'
            d={line().x(d => d[0]).y(d => d[1])(line2)}
          />
            <path 
            fill='rgba(0,255,0,0.2)'
            d={line().x(d => d[0]).y(d => d[1])(line3)}
          />
          </g>
          {
          	data.map(d => <g opacity="0.6" transform={`translate(${xScale(xValue(d))},${yScale(yValue(d))})`}>
                     	<circle 
                        r={7}
                        fill={colorScale(d.species)}
                        />
                     </g>) 
          }
        </g>
      </svg>
    </>
  );
  
}

ReactDOM.render(<App />, document.getElementById('root'));
